@@ -17,23 +17,16 @@ void gram_PIPETHROUGH()
         message("PIPETHROUGH echo '%s' | %s", string_short(input), short_cmd);
     free(short_cmd);
 
-    if (!check_live_data(cmd))
-    {
-        free(input);
-        free(cmd);
-    }
-    else
-    {
-        Process process;
-        String const *output;
+    Process process;
+    String const *output;
 
-        process_construct (&process, "PIPETHROUGH", cmd, input);
-        process_fork(&process);
-        output = process_output(&process);
+    process_construct (&process, "PIPETHROUGH", cmd, input);
+    process_fork(&process);
+    output = process_output(&process);
 
-        lexer_push_str(&parser.d_lexer, string_str(output));
+    lexer_push_str(&parser.d_lexer, string_str(output));
+
+    process_destroy(&process);
 
-        process_destroy(&process);
-    }
     parser_pop_fun();
 }
